@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import locale
 import logging
 import os
@@ -5,17 +7,19 @@ import re
 import shlex
 import subprocess
 from time import sleep
+from typing import Any, Generator
 
 import click
+from configobj import ConfigObj
+from pymysql.cursors import Cursor
 import pyperclip
-import sqlglot
 import sqlparse
 
+from mycli.compat import WIN
 from mycli.packages.prompt_utils import confirm_destructive_query
-from mycli.packages.special import export
 from mycli.packages.special.delimitercommand import DelimiterCommand
 from mycli.packages.special.favoritequeries import FavoriteQueries
-from mycli.packages.special.main import NO_QUERY, PARSED_QUERY, special_command
+from mycli.packages.special.main import ArgType, special_command
 from mycli.packages.special.utils import handle_cd_command
 
 TIMING_ENABLED = False
@@ -25,40 +29,51 @@ PAGER_ENABLED = True
 tee_file = None
 once_file = None
 written_to_once_file = False
-pipe_once_process = None
-pipe_once_stdin = []
+PIPE_ONCE: dict[str, Any] = {
+    'process': None,
+    'stdin': [],
+    'stdout_file': None,
+    'stdout_mode': None,
+}
 delimiter_command = DelimiterCommand()
+favoritequeries = FavoriteQueries(ConfigObj())
 
 
-@export
-def set_timing_enabled(val):
+def set_favorite_queries(config):
+    global favoritequeries
+    favoritequeries = FavoriteQueries(config)
+
+
+def set_timing_enabled(val: bool) -> None:
     global TIMING_ENABLED
     TIMING_ENABLED = val
 
 
-@export
-def set_pager_enabled(val):
+def set_pager_enabled(val: bool) -> None:
     global PAGER_ENABLED
     PAGER_ENABLED = val
 
 
-@export
-def is_pager_enabled():
+def is_pager_enabled() -> bool:
     return PAGER_ENABLED
 
 
-@export
 @special_command(
-    "pager", "\\P [command]", "Set PAGER. Print the query results via PAGER.", arg_type=PARSED_QUERY, aliases=("\\P",), case_sensitive=True
+    "pager",
+    "\\P [command]",
+    "Set PAGER. Print the query results via PAGER.",
+    arg_type=ArgType.PARSED_QUERY,
+    aliases=["\\P"],
+    case_sensitive=True,
 )
-def set_pager(arg, **_):
+def set_pager(arg: str, **_) -> list[tuple]:
     if arg:
         os.environ["PAGER"] = arg
-        msg = "PAGER set to %s." % arg
+        msg = f"PAGER set to {arg}."
         set_pager_enabled(True)
     else:
         if "PAGER" in os.environ:
-            msg = "PAGER set to %s." % os.environ["PAGER"]
+            msg = f"PAGER set to {os.environ['PAGER']}."
         else:
             # This uses click's default per echo_via_pager.
             msg = "Pager enabled."
@@ -67,15 +82,14 @@ def set_pager(arg, **_):
     return [(None, None, None, msg)]
 
 
-@export
-@special_command("nopager", "\\n", "Disable pager, print to stdout.", arg_type=NO_QUERY, aliases=("\\n",), case_sensitive=True)
-def disable_pager():
+@special_command("nopager", "\\n", "Disable pager, print to stdout.", arg_type=ArgType.NO_QUERY, aliases=["\\n"], case_sensitive=True)
+def disable_pager() -> list[tuple]:
     set_pager_enabled(False)
     return [(None, None, None, "Pager disabled.")]
 
 
-@special_command("\\timing", "\\t", "Toggle timing of commands.", arg_type=NO_QUERY, aliases=("\\t",), case_sensitive=True)
-def toggle_timing():
+@special_command("\\timing", "\\t", "Toggle timing of commands.", arg_type=ArgType.NO_QUERY, aliases=["\\t"], case_sensitive=True)
+def toggle_timing() -> list[tuple]:
     global TIMING_ENABLED
     TIMING_ENABLED = not TIMING_ENABLED
     message = "Timing is "
@@ -83,38 +97,32 @@ def toggle_timing():
     return [(None, None, None, message)]
 
 
-@export
-def is_timing_enabled():
+def is_timing_enabled() -> bool:
     return TIMING_ENABLED
 
 
-@export
-def set_expanded_output(val):
+def set_expanded_output(val: bool) -> None:
     global use_expanded_output
     use_expanded_output = val
 
 
-@export
-def is_expanded_output():
+def is_expanded_output() -> bool:
     return use_expanded_output
 
 
-@export
-def set_forced_horizontal_output(val):
+def set_forced_horizontal_output(val: bool) -> None:
     global force_horizontal_output
     force_horizontal_output = val
 
 
-@export
-def forced_horizontal():
+def forced_horizontal() -> bool:
     return force_horizontal_output
 
 
 _logger = logging.getLogger(__name__)
 
 
-@export
-def editor_command(command):
+def editor_command(command: str) -> bool:
     """
     Is this an external editor command?
     :param command: string
@@ -124,15 +132,15 @@ def editor_command(command):
     return command.strip().endswith("\\e") or command.strip().startswith("\\e")
 
 
-@export
-def get_filename(sql):
+def get_filename(sql: str) -> str | None:
     if sql.strip().startswith("\\e"):
         command, _, filename = sql.partition(" ")
         return filename.strip() or None
+    else:
+        return None
 
 
-@export
-def get_editor_query(sql):
+def get_editor_query(sql: str) -> str:
     """Get the query part of an editor command."""
     sql = sql.strip()
 
@@ -146,44 +154,41 @@ def get_editor_query(sql):
     return sql
 
 
-@export
-def open_external_editor(filename=None, sql=None):
+def open_external_editor(filename: str | None = None, sql: str | None = None) -> tuple[str, str | None]:
     """Open external editor, wait for the user to type in their query, return
     the query.
-
-    :return: list with one tuple, query as first element.
-
     """
 
-    message = None
     filename = filename.strip().split(" ", 1)[0] if filename else None
-
     sql = sql or ""
     MARKER = "# Type your query above this line.\n"
 
-    # Populate the editor buffer with the partial sql (if available) and a
-    # placeholder comment.
-    query = click.edit("{sql}\n\n{marker}".format(sql=sql, marker=MARKER), filename=filename, extension=".sql")
-
     if filename:
+        query = ''
+        message = None
+        click.edit(filename=filename)
         try:
-            with open(filename) as f:
+            with open(filename, 'r') as f:
                 query = f.read()
         except IOError:
-            message = "Error reading file: %s." % filename
+            message = f'Error reading file: {filename}'
+        return (query, message)
 
-    if query is not None:
+    # Populate the editor buffer with the partial sql (if available) and a
+    # placeholder comment.
+    query = click.edit(f"{sql}\n\n{MARKER}", extension=".sql") or ''
+
+    if query:
         query = query.split(MARKER, 1)[0].rstrip("\n")
     else:
         # Don't return None for the caller to deal with.
         # Empty string is ok.
         query = sql
 
-    return (query, message)
+    return (query, None)
 
 
-@export
-def clip_command(command):
+def clip_command(command: str) -> bool:
     """Is this a clip command?
 
     :param command: string
@@ -194,8 +199,7 @@ def clip_command(command):
     return command.strip().endswith("\\clip") or command.strip().startswith("\\clip")
 
 
-@export
-def get_clip_query(sql):
+def get_clip_query(sql: str) -> str:
     """Get the query part of a clip command."""
     sql = sql.strip()
 
@@ -208,107 +212,46 @@ def get_clip_query(sql):
     return sql
 
 
-@export
-def copy_query_to_clipboard(sql=None):
+def copy_query_to_clipboard(sql: str | None = None) -> str | None:
     """Send query to the clipboard."""
 
     sql = sql or ""
     message = None
 
     try:
-        pyperclip.copy("{sql}".format(sql=sql))
+        pyperclip.copy(f"{sql}")
     except RuntimeError as e:
-        message = "Error clipping query: %s." % e.strerror
+        message = f"Error clipping query: {e}."
 
     return message
 
 
-@export
-def is_redirect_command(command: str) -> bool:
-    """Is this a shell-style redirect command?
-
-    :param command: string
-
-    """
-    sql_string, operator, shell_string = get_redirect_components(command)
-    return bool(sql_string)
-
-
-@export
-def get_redirect_components(command: str):
-    """Get the parts of a shell-style redirect command."""
-
-    dollar_pos = 0
-    operator_pos = 0
-    try:
-        tokens = sqlglot.tokenize(command)
-    except sqlglot.errors.TokenError:
-        return None, None, None
-    for tok in reversed(tokens):
-        if tok.token_type in (sqlglot.TokenType.GT, sqlglot.TokenType.PIPE):
-            operator_pos = tok.start
-            continue
-        if tok.token_type == sqlglot.TokenType.VAR and tok.text == '$' and tok.start == operator_pos - 1:
-            dollar_pos = tok.start
-            break
-
-    sql_string = command[0:dollar_pos].strip().removesuffix(get_current_delimiter()).rstrip()
-    try:
-        statements = sqlglot.parse(sql_string, read='mysql')
-    except sqlglot.errors.ParseError:
-        return None, None, None
-    if len(statements) != 1:
-        # buglet: the statement count doesn't respect a custom delimiter
-        return None, None, None
-
-    operator_string = ''
-    shell_string = command[operator_pos:]
-    for op in ['>>', '>', '|']:
-        if shell_string.startswith(op):
-            operator_string = op
-            shell_string = shell_string.removeprefix(op)
-            break
-    shell_string = shell_string.strip().removesuffix(get_current_delimiter()).rstrip()
-
-    if ' ' in shell_string and operator_string.startswith('>'):
-        return None, None, None
-
-    if '>' in shell_string and operator_string.startswith('>'):
-        return None, None, None
-
-    if not shell_string:
-        return None, None, None
-
-    if not sql_string:
-        return None, None, None
-
-    return sql_string, operator_string, shell_string
-
-
-@export
-def set_redirect(filename: str, operator: str):
-    if operator == '|':
-        return set_pipe_once(filename)
-    elif operator == '>':
-        return set_once(f'-o {filename}')
+def set_redirect(command_part: str | None, file_operator_part: str | None, file_part: str | None) -> list[tuple]:
+    if command_part:
+        if file_part:
+            PIPE_ONCE['stdout_file'] = file_part
+            PIPE_ONCE['stdout_mode'] = 'w' if file_operator_part == '>' else 'a'
+        return set_pipe_once(command_part)
+    elif file_operator_part == '>':
+        return set_once(f'-o {file_part}')
     else:
-        return set_once(filename)
+        return set_once(file_part)
 
 
-@special_command("\\f", "\\f [name [args..]]", "List or execute favorite queries.", arg_type=PARSED_QUERY, case_sensitive=True)
-def execute_favorite_query(cur, arg, **_):
+@special_command("\\f", "\\f [name [args..]]", "List or execute favorite queries.", arg_type=ArgType.PARSED_QUERY, case_sensitive=True)
+def execute_favorite_query(cur: Cursor, arg: str, **_) -> Generator[tuple, None, None]:
     """Returns (title, rows, headers, status)"""
     if arg == "":
         for result in list_favorite_queries():
             yield result
 
-    """Parse out favorite name and optional substitution parameters"""
-    name, _, arg_str = arg.partition(" ")
+    # Parse out favorite name and optional substitution parameters
+    name, _separator, arg_str = arg.partition(" ")
     args = shlex.split(arg_str)
 
     query = FavoriteQueries.instance.get(name)
     if query is None:
-        message = "No favorite query: %s" % (name)
+        message = f"No favorite query: {name}"
         yield (None, None, None, message)
     else:
         query, arg_error = subst_favorite_query_args(query, args)
@@ -317,7 +260,7 @@ def execute_favorite_query(cur, arg, **_):
         else:
             for sql in sqlparse.split(query):
                 sql = sql.rstrip(";")
-                title = "> %s" % (sql)
+                title = f"> {sql}"
                 cur.execute(sql)
                 if cur.description:
                     headers = [x[0] for x in cur.description]
@@ -326,7 +269,7 @@ def execute_favorite_query(cur, arg, **_):
                     yield (title, None, None, None)
 
 
-def list_favorite_queries():
+def list_favorite_queries() -> list[tuple]:
     """List of all favorite queries.
     Returns (title, rows, headers, status)"""
 
@@ -340,7 +283,7 @@ def list_favorite_queries():
     return [("", rows, headers, status)]
 
 
-def subst_favorite_query_args(query, args):
+def subst_favorite_query_args(query: str, args: list[str]) -> list[str | None]:
     """replace positional parameters ($1...$N) in query."""
     for idx, val in enumerate(args):
         subst_var = "$" + str(idx + 1)
@@ -357,7 +300,7 @@ def subst_favorite_query_args(query, args):
 
 
 @special_command("\\fs", "\\fs name query", "Save a favorite query.")
-def save_favorite_query(arg, **_):
+def save_favorite_query(arg: str, **_) -> list[tuple]:
     """Save a new favorite query.
     Returns (title, rows, headers, status)"""
 
@@ -365,7 +308,7 @@ def save_favorite_query(arg, **_):
     if not arg:
         return [(None, None, None, usage)]
 
-    name, _, query = arg.partition(" ")
+    name, _separator, query = arg.partition(" ")
 
     # If either name or query is missing then print the usage and complain.
     if (not name) or (not query):
@@ -376,7 +319,7 @@ def save_favorite_query(arg, **_):
 
 
 @special_command("\\fd", "\\fd [name]", "Delete a favorite query.")
-def delete_favorite_query(arg, **_):
+def delete_favorite_query(arg: str, **_) -> list[tuple]:
     """Delete an existing favorite query."""
     usage = "Syntax: \\fd name.\n\n" + FavoriteQueries.instance.usage
     if not arg:
@@ -388,7 +331,7 @@ def delete_favorite_query(arg, **_):
 
 
 @special_command("system", "system [command]", "Execute a system shell commmand.")
-def execute_system_command(arg, **_):
+def execute_system_command(arg: str, **_) -> list[tuple]:
     """Execute a system shell command."""
     usage = "Syntax: system [command].\n"
 
@@ -408,17 +351,15 @@ def execute_system_command(arg, **_):
         output, error = process.communicate()
         response = output if not error else error
 
-        # Python 3 returns bytes. This needs to be decoded to a string.
-        if isinstance(response, bytes):
-            encoding = locale.getpreferredencoding(False)
-            response = response.decode(encoding)
+        encoding = locale.getpreferredencoding(False)
+        response_str = response.decode(encoding)
 
-        return [(None, None, None, response)]
+        return [(None, None, None, response_str)]
     except OSError as e:
-        return [(None, None, None, "OSError: %s" % e.strerror)]
+        return [(None, None, None, f"OSError: {e.strerror}")]
 
 
-def parseargfile(arg):
+def parseargfile(arg: str) -> tuple[str, str]:
     if arg.startswith("-o "):
         mode = "w"
         filename = arg[3:]
@@ -429,23 +370,22 @@ def parseargfile(arg):
     if not filename:
         raise TypeError("You must provide a filename.")
 
-    return {"file": os.path.expanduser(filename), "mode": mode}
+    return (os.path.expanduser(filename), mode)
 
 
 @special_command("tee", "tee [-o] filename", "Append all results to an output file (overwrite using -o).")
-def set_tee(arg, **_):
+def set_tee(arg: str, **_) -> list[tuple]:
     global tee_file
 
     try:
-        tee_file = open(**parseargfile(arg))
+        tee_file = open(*parseargfile(arg))
     except (IOError, OSError) as e:
-        raise OSError("Cannot write to file '{}': {}".format(e.filename, e.strerror))
+        raise OSError(f"Cannot write to file '{e.filename}': {e.strerror}")
 
     return [(None, None, None, "")]
 
 
-@export
-def close_tee():
+def close_tee() -> None:
     global tee_file
     if tee_file:
         tee_file.close()
@@ -453,13 +393,12 @@ def close_tee():
 
 
 @special_command("notee", "notee", "Stop writing results to an output file.")
-def no_tee(arg, **_):
+def no_tee(arg: str, **_) -> list[tuple]:
     close_tee()
     return [(None, None, None, "")]
 
 
-@export
-def write_tee(output):
+def write_tee(output: str) -> None:
     global tee_file
     if tee_file:
         click.echo(output, file=tee_file, nl=False)
@@ -467,26 +406,24 @@ def write_tee(output):
         tee_file.flush()
 
 
-@special_command("\\once", "\\o [-o] filename", "Append next result to an output file (overwrite using -o).", aliases=("\\o",))
-def set_once(arg, **_):
+@special_command("\\once", "\\o [-o] filename", "Append next result to an output file (overwrite using -o).", aliases=["\\o"])
+def set_once(arg: str, **_) -> list[tuple]:
     global once_file, written_to_once_file
 
     try:
-        once_file = open(**parseargfile(arg))
+        once_file = open(*parseargfile(arg))
     except (IOError, OSError) as e:
-        raise OSError("Cannot write to file '{}': {}".format(e.filename, e.strerror))
+        raise OSError(f"Cannot write to file '{e.filename}': {e.strerror}")
     written_to_once_file = False
 
     return [(None, None, None, "")]
 
 
-@export
-def is_redirected():
-    return bool(once_file or pipe_once_process)
+def is_redirected() -> bool:
+    return bool(once_file or PIPE_ONCE['process'])
 
 
-@export
-def write_once(output):
+def write_once(output: str) -> None:
     global once_file, written_to_once_file
     if output and once_file:
         click.echo(output, file=once_file, nl=False)
@@ -495,37 +432,45 @@ def write_once(output):
         written_to_once_file = True
 
 
-@export
-def unset_once_if_written(post_redirect_command) -> None:
+def unset_once_if_written(post_redirect_command: str) -> None:
     """Unset the once file, if it has been written to."""
     global once_file, written_to_once_file
     if written_to_once_file and once_file:
         once_filename = once_file.name
         once_file.close()
         once_file = None
-        if post_redirect_command:
-            post_cmd = post_redirect_command.format(shlex.quote(once_filename))
-            try:
-                subprocess.run(
-                    post_cmd,
-                    shell=True,
-                    check=True,
-                    stdin=subprocess.DEVNULL,
-                    stdout=subprocess.DEVNULL,
-                    stderr=subprocess.DEVNULL,
-                )
-            except Exception as e:
-                raise OSError("Redirect post hook failed: {}".format(e))
+        _run_post_redirect_hook(post_redirect_command, once_filename)
 
 
-@special_command("\\pipe_once", "\\| command", "Send next result to a subprocess.", aliases=("\\|",))
-def set_pipe_once(arg, **_):
-    global pipe_once_process, pipe_once_stdin
-    pipe_once_cmd = shlex.split(arg)
-    if len(pipe_once_cmd) == 0:
+def _run_post_redirect_hook(post_redirect_command: str, filename: str) -> None:
+    if not post_redirect_command:
+        return
+    post_cmd = post_redirect_command.format(shlex.quote(filename))
+    try:
+        subprocess.run(
+            post_cmd,
+            shell=True,
+            check=True,
+            stdin=subprocess.DEVNULL,
+            stdout=subprocess.DEVNULL,
+            stderr=subprocess.DEVNULL,
+        )
+    except Exception as e:
+        raise OSError(f"Redirect post hook failed: {e}")
+
+
+@special_command("\\pipe_once", "\\| command", "Send next result to a subprocess.", aliases=["\\|"])
+def set_pipe_once(arg: str, **_) -> list[tuple]:
+    if not arg:
         raise OSError("pipe_once requires a command")
-    pipe_once_stdin = []
-    pipe_once_process = subprocess.Popen(
+    if WIN:
+        # best effort, no chaining
+        pipe_once_cmd = shlex.split(arg)
+    else:
+        # to support chaining
+        pipe_once_cmd = ['sh', '-c', arg]
+    PIPE_ONCE['stdin'] = []
+    PIPE_ONCE['process'] = subprocess.Popen(
         pipe_once_cmd,
         stdin=subprocess.PIPE,
         stdout=subprocess.PIPE,
@@ -536,38 +481,45 @@ def set_pipe_once(arg, **_):
     return [(None, None, None, "")]
 
 
-@export
-def write_pipe_once(line):
-    global pipe_once_process, pipe_once_stdin
-    if line and pipe_once_process:
-        pipe_once_stdin.append(line)
+def write_pipe_once(line: str) -> None:
+    if line and PIPE_ONCE['process']:
+        PIPE_ONCE['stdin'].append(line)
 
 
-@export
-def flush_pipe_once_if_written():
+def flush_pipe_once_if_written(post_redirect_command: str) -> None:
     """Flush the pipe_once cmd, if lines have been written."""
-    global pipe_once_process, pipe_once_stdin
-    if not pipe_once_process:
+    if not PIPE_ONCE['process']:
         return
-    if not pipe_once_stdin:
+    if not PIPE_ONCE['stdin']:
         return
     try:
-        (stdout_data, stderr_data) = pipe_once_process.communicate(input='\n'.join(pipe_once_stdin) + '\n', timeout=60)
+        (stdout_data, stderr_data) = PIPE_ONCE['process'].communicate(input='\n'.join(PIPE_ONCE['stdin']) + '\n', timeout=60)
     except subprocess.TimeoutExpired:
-        pipe_once_process.kill()
-        (stdout_data, stderr_data) = pipe_once_process.communicate()
+        PIPE_ONCE['process'].kill()
+        (stdout_data, stderr_data) = PIPE_ONCE['process'].communicate()
     if stdout_data:
-        click.secho(stdout_data.rstrip('\n'))
+        if PIPE_ONCE['stdout_file']:
+            with open(PIPE_ONCE['stdout_file'], PIPE_ONCE['stdout_mode']) as f:
+                print(stdout_data, file=f)
+            _run_post_redirect_hook(post_redirect_command, PIPE_ONCE['stdout_file'])
+        else:
+            click.secho(stdout_data.rstrip('\n'))
     if stderr_data:
         click.secho(stderr_data.rstrip('\n'), err=True, fg='red')
-    if pipe_once_process.returncode:
-        click.secho(f'process exited with nonzero code {pipe_once_process.returncode}', err=True, fg='red')
-    pipe_once_process = None
-    pipe_once_stdin = []
+    if returncode := PIPE_ONCE['process'].returncode:
+        PIPE_ONCE['process'] = None
+        PIPE_ONCE['stdin'] = []
+        PIPE_ONCE['stdout_file'] = None
+        PIPE_ONCE['stdout_mode'] = None
+        raise OSError(f'process exited with nonzero code {returncode}')
+    PIPE_ONCE['process'] = None
+    PIPE_ONCE['stdin'] = []
+    PIPE_ONCE['stdout_file'] = None
+    PIPE_ONCE['stdout_mode'] = None
 
 
 @special_command("watch", "watch [seconds] [-c] query", "Executes the query every [seconds] seconds (by default 5).")
-def watch_query(arg, **kwargs):
+def watch_query(arg: str, **kwargs) -> Generator[tuple, None, None]:
     usage = """Syntax: watch [seconds] [-c] query.
     * seconds: The interval at the query will be repeated, in seconds.
                By default 5.
@@ -576,7 +528,7 @@ def watch_query(arg, **kwargs):
     if not arg:
         yield (None, None, None, usage)
         return
-    seconds = 5
+    seconds = 5.0
     clear_screen = False
     statement = None
     while statement is None:
@@ -585,16 +537,17 @@ def watch_query(arg, **kwargs):
             # Oops, we parsed all the arguments without finding a statement
             yield (None, None, None, usage)
             return
-        (current_arg, _, arg) = arg.partition(" ")
+        (left_arg, _, right_arg) = arg.partition(" ")
+        arg = right_arg
         try:
-            seconds = float(current_arg)
+            seconds = float(left_arg)
             continue
         except ValueError:
             pass
-        if current_arg == "-c":
+        if left_arg == "-c":
             clear_screen = True
             continue
-        statement = "{0!s} {1!s}".format(current_arg, arg)
+        statement = f"{left_arg} {arg}"
     destructive_prompt = confirm_destructive_query(statement)
     if destructive_prompt is False:
         click.secho("Wise choice!")
@@ -602,7 +555,7 @@ def watch_query(arg, **kwargs):
     elif destructive_prompt is True:
         click.secho("Your call!")
     cur = kwargs["cur"]
-    sql_list = [(sql.rstrip(";"), "> {0!s}".format(sql)) for sql in sqlparse.split(statement)]
+    sql_list = [(sql.rstrip(";"), f"> {sql}") for sql in sqlparse.split(statement)]
     old_pager_enabled = is_pager_enabled()
     while True:
         if clear_screen:
@@ -628,18 +581,15 @@ def watch_query(arg, **kwargs):
             set_pager_enabled(old_pager_enabled)
 
 
-@export
 @special_command("delimiter", None, "Change SQL delimiter.")
-def set_delimiter(arg, **_):
+def set_delimiter(arg: str, **_) -> list[tuple]:
     return delimiter_command.set(arg)
 
 
-@export
-def get_current_delimiter():
+def get_current_delimiter() -> str:
     return delimiter_command.current
 
 
-@export
-def split_queries(input_str):
+def split_queries(input_str: str) -> Generator[str, None, None]:
     for query in delimiter_command.queries_iter(input_str):
         yield query
