@@ -223,7 +223,7 @@ def test_watch_query_full():
     expected_value = "1"
     query = f"SELECT {expected_value}"
     expected_title = f"> {query}"
-    expected_results = [4, 5]
+    expected_results = [4, 5, 6, 7]  # Python 3.14 is skipping ahead to 6 or 7
     ctrl_c_process = send_ctrl_c(wait_interval)
     with db_connection().cursor() as cur:
         results = list(mycli.packages.special.iocommands.watch_query(arg=f"{watch_seconds} {query}", cur=cur))
